@@ -13,10 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import jsonschema
+import ddt
 import mock
 
-from rally import exceptions
 from rally.plugins.common.runners import constant
 from rally.task import runner
 from tests.unit import fakes
@@ -27,6 +26,7 @@ RUNNERS_BASE = "rally.task.runner."
 RUNNERS = "rally.plugins.common.runners."
 
 
+@ddt.ddt
 class ConstantScenarioRunnerTestCase(test.TestCase):
 
     def setUp(self):
@@ -38,29 +38,23 @@ class ConstantScenarioRunnerTestCase(test.TestCase):
         self.args = {"a": 1}
         self.task = mock.MagicMock()
 
-    def test_validate(self):
-        constant.ConstantScenarioRunner.validate(self.config)
-
-    def test_validate_failed_by_additional_key(self):
-        self.config["new_key"] = "should fail"
-        self.assertRaises(jsonschema.ValidationError,
-                          constant.ConstantScenarioRunner.validate,
-                          self.config)
-
-    def test_validate_failed_by_wrong_concurrency(self):
-        self.config["concurrency"] = self.config["times"] + 1
-        self.assertRaises(exceptions.ValidationError,
-                          constant.ConstantScenarioRunner.validate,
-                          self.config)
-
-    @mock.patch(RUNNERS + "constant.runner")
-    def test__run_scenario_once_with_unpack_args(self, mock_runner):
-        result = constant._run_scenario_once_with_unpack_args(
-            ("FOO", ("BAR", "QUUZ")))
-
-        self.assertEqual(mock_runner._run_scenario_once.return_value, result)
-        mock_runner._run_scenario_once.assert_called_once_with(
-            "FOO", ("BAR", "QUUZ"))
+    @ddt.data(({"times": 4,
+                "concurrency": 2,
+                "timeout": 2,
+                "max_cpu_count": 2}, True),
+              ({"times": 4,
+                "concurrency": 5,
+                "timeout": 2,
+                "max_cpu_count": 2}, False),
+              ({"foo": "bar"}, False))
+    @ddt.unpack
+    def test_validate(self, config, valid):
+        results = runner.ScenarioRunner.validate(
+            "constant", None, None, config)
+        if valid:
+            self.assertEqual([], results)
+        else:
+            self.assertGreater(len(results), 0)
 
     @mock.patch(RUNNERS + "constant.time")
     @mock.patch(RUNNERS + "constant.threading.Thread")
@@ -86,7 +80,7 @@ class ConstantScenarioRunnerTestCase(test.TestCase):
                               "id": "uuid1"}]}
         info = {"processes_to_start": 1, "processes_counter": 1}
 
-        constant._worker_process(mock_queue, fake_ram_int, 1, 2, times,
+        constant._worker_process(mock_queue, fake_ram_int, 1, 2, times, None,
                                  context, "Dummy", "dummy", (),
                                  mock_event_queue, mock_event, info)
 
@@ -128,7 +122,7 @@ class ConstantScenarioRunnerTestCase(test.TestCase):
 
         runner_obj._run_scenario(
             fakes.FakeScenario, "do_it", self.context, self.args)
-        self.assertEqual(len(runner_obj.result_queue), self.config["times"])
+        self.assertEqual(self.config["times"], len(runner_obj.result_queue))
         for result_batch in runner_obj.result_queue:
             for result in result_batch:
                 self.assertIsNotNone(result)
@@ -138,7 +132,7 @@ class ConstantScenarioRunnerTestCase(test.TestCase):
 
         runner_obj._run_scenario(fakes.FakeScenario, "something_went_wrong",
                                  self.context, self.args)
-        self.assertEqual(len(runner_obj.result_queue), self.config["times"])
+        self.assertEqual(self.config["times"], len(runner_obj.result_queue))
         for result_batch in runner_obj.result_queue:
             for result in result_batch:
                 self.assertIsNotNone(result)
@@ -150,7 +144,7 @@ class ConstantScenarioRunnerTestCase(test.TestCase):
         runner_obj.abort()
         runner_obj._run_scenario(fakes.FakeScenario, "do_it", self.context,
                                  self.args)
-        self.assertEqual(len(runner_obj.result_queue), 0)
+        self.assertEqual(0, len(runner_obj.result_queue))
 
     @mock.patch(RUNNERS + "constant.multiprocessing.Queue")
     @mock.patch(RUNNERS + "constant.multiprocessing.cpu_count")
@@ -255,6 +249,7 @@ class ConstantScenarioRunnerTestCase(test.TestCase):
         self.assertTrue(runner_obj.aborted.is_set())
 
 
+@ddt.ddt
 class ConstantForDurationScenarioRunnerTestCase(test.TestCase):
 
     def setUp(self):
@@ -264,38 +259,45 @@ class ConstantForDurationScenarioRunnerTestCase(test.TestCase):
         self.context = fakes.FakeContext({"task": {"uuid": "uuid"}}).context
         self.context["iteration"] = 14
         self.args = {"a": 1}
+        self.task = mock.MagicMock()
 
-    def test_validate(self):
-        constant.ConstantForDurationScenarioRunner.validate(self.config)
-
-    def test_validate_failed(self):
-        self.config["times"] = "gagaga"
-        self.assertRaises(jsonschema.ValidationError,
-                          runner.ScenarioRunner.validate,
-                          self.config)
+    @ddt.data(({"duration": 0,
+                "concurrency": 2,
+                "timeout": 2}, True),
+              ({"foo": "bar"}, False))
+    @ddt.unpack
+    def test_validate(self, config, valid):
+        results = runner.ScenarioRunner.validate(
+            "constant_for_duration", None, None, config)
+        if valid:
+            self.assertEqual([], results)
+        else:
+            self.assertGreater(len(results), 0)
 
     def test_run_scenario_constantly_for_duration(self):
         runner_obj = constant.ConstantForDurationScenarioRunner(
-            None, self.config)
+            mock.MagicMock(), self.config)
 
         runner_obj._run_scenario(fakes.FakeScenario, "do_it",
                                  self.context, self.args)
-        # NOTE(mmorais): when duration is 0, scenario executes exactly 1 time
-        expected_times = 1
-        self.assertEqual(len(runner_obj.result_queue), expected_times)
+        # NOTE(mmorais/msimonin): when duration is 0, scenario executes exactly
+        # 1 time per unit of parrallelism
+        expected_times = self.config["concurrency"]
+        self.assertEqual(expected_times, len(runner_obj.result_queue))
         for result_batch in runner_obj.result_queue:
             for result in result_batch:
                 self.assertIsNotNone(result)
 
     def test_run_scenario_constantly_for_duration_exception(self):
         runner_obj = constant.ConstantForDurationScenarioRunner(
-            None, self.config)
+            mock.MagicMock(), self.config)
 
         runner_obj._run_scenario(fakes.FakeScenario, "something_went_wrong",
                                  self.context, self.args)
-        # NOTE(mmorais): when duration is 0, scenario executes exactly 1 time
-        expected_times = 1
-        self.assertEqual(len(runner_obj.result_queue), expected_times)
+        # NOTE(mmorais/msimonin): when duration is 0, scenario executes exactly
+        # 1 time per unit of parrallelism
+        expected_times = self.config["concurrency"]
+        self.assertEqual(expected_times, len(runner_obj.result_queue))
         for result_batch in runner_obj.result_queue:
             for result in result_batch:
                 self.assertIsNotNone(result)
@@ -303,26 +305,27 @@ class ConstantForDurationScenarioRunnerTestCase(test.TestCase):
 
     def test_run_scenario_constantly_for_duration_timeout(self):
         runner_obj = constant.ConstantForDurationScenarioRunner(
-            None, self.config)
+            mock.MagicMock(), self.config)
 
         runner_obj._run_scenario(fakes.FakeScenario, "raise_timeout",
                                  self.context, self.args)
-        # NOTE(mmorais): when duration is 0, scenario executes exactly 1 time
-        expected_times = 1
-        self.assertEqual(len(runner_obj.result_queue), expected_times)
+        # NOTE(mmorais/msimonin): when duration is 0, scenario executes exactly
+        # 1 time per unit of parrallelism
+        expected_times = self.config["concurrency"]
+        self.assertEqual(expected_times, len(runner_obj.result_queue))
         for result_batch in runner_obj.result_queue:
             for result in result_batch:
                 self.assertIsNotNone(result)
         self.assertIn("error", runner_obj.result_queue[0][0])
 
     def test__run_scenario_constantly_aborted(self):
-        runner_obj = constant.ConstantForDurationScenarioRunner(None,
+        runner_obj = constant.ConstantForDurationScenarioRunner(self.task,
                                                                 self.config)
 
         runner_obj.abort()
         runner_obj._run_scenario(fakes.FakeScenario, "do_it",
                                  self.context, self.args)
-        self.assertEqual(len(runner_obj.result_queue), 0)
+        self.assertEqual(0, len(runner_obj.result_queue))
 
     def test_abort(self):
         runner_obj = constant.ConstantForDurationScenarioRunner(None,
